@@ -1,38 +1,22 @@
 /*
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
 
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_PREFS_H
 #define EVENTVIEWS_PREFS_H
 
-#include "eventviews_export.h"
 #include "eventview.h"
+#include "eventviews_export.h"
 
 #include <KConfigSkeleton>
 
 #include <QTimeZone>
 
-namespace EventViews {
+namespace EventViews
+{
 class EVENTVIEWS_EXPORT Prefs
 {
 public:
@@ -82,7 +66,7 @@ public:
 
     void setSelectionStartsEditor(bool startEditor);
     Q_REQUIRED_RESULT bool selectionStartsEditor() const;
-    
+
     void setUseSystemColor(bool useSystemColor);
     Q_REQUIRED_RESULT bool useSystemColor() const;
 
@@ -224,7 +208,7 @@ private:
     Private *const d;
 };
 
-typedef QSharedPointer<Prefs> PrefsPtr;
+using PrefsPtr = QSharedPointer<Prefs>;
 }
 
 #endif
